Enum ethcontract::contract::EventStatus
source · pub enum EventStatus<T> {
Added(T),
Removed(T),
}Expand description
A type representing a contract event that was either added or removed. Note that this type intentionally an enum so that the handling of removed events is made more explicit.
Variants
Added(T)
A new event was received.
Removed(T)
A previously mined event was removed as a result of a re-org.