Struct ethcontract::contract::EventMetadata

source ·
pub struct EventMetadata {
    pub address: H160,
    pub block_hash: H256,
    pub block_number: u64,
    pub transaction_hash: H256,
    pub transaction_index: usize,
    pub log_index: usize,
    pub transaction_log_index: Option<usize>,
    pub log_type: Option<String>,
}
Additional metadata from the log for the event.

Fields

address: H160

From which this event originated from

block_hash: H256

The hash of the block where the log was produced.

block_number: u64

The number of the block where the log was produced.

transaction_hash: H256

The hash of the transaction this log belongs to.

transaction_index: usize

The block index of the transaction this log belongs to.

log_index: usize

The index of the log in the block.

transaction_log_index: Option<usize>

The log index in the transaction this log belongs to. This property is non-standard.

log_type: Option<String>

The log type. Note that this property is non-standard but is supported by Parity nodes.