Struct ethcontract::contract::Linker

source ·
pub struct Linker { /* private fields */ }
Builder for specifying linking options for a contract.

Implementations

source

impl Linker

source

pub fn new(contract: Contract) -> Linker

Create a new linker for a contract.

source

pub fn library<S>(self, name: S, address: Address) -> Result<Linker, LinkError>
where S: AsRef<str>,

Specify a linked library used for this contract. Note that we incrementally link so that we can verify each time a library is linked whether it was successful or not.

Panics

Panics if an invalid library name is used (for example if it is more than 38 characters long).

source

pub fn deploy<T, P>( self, web3: Web3<T>, params: P ) -> Result<DeployBuilder<T, Instance<T>>, DeployError>
where T: Transport, P: Tokenize,

Finish linking and check if there are any outstanding unlinked libraries and create a deployment builder.