RawLog

Struct RawLog 

pub struct RawLog {
    pub topics: Vec<H256>,
    pub data: Vec<u8>,
}
Raw log topics and data for a contract event.

Fields

topics: Vec<H256>

The raw 32-byte topics.

data: Vec<u8>

The raw non-indexed data attached to an event.

Implementations

Source

impl RawLog

pub fn decode<D>(self, event: &AbiEvent) -> Result<D, ExecutionError>
where D: Tokenize,

Decode raw log data into a tokenizable for a matching event ABI entry.