Module dyns

Module dyns 

Type aliases to various runtime types that use an underlying DynTransport. These types are used extensively throughout the generated code.

Re-exports

pub use crate::transport::DynTransport;

Type Aliases

DynAllEventsBuilder
Type alias for a LogStream with an underlying DynTransport.
DynDeployBuilder
Type alias for a DeployBuilder with an underlying DynTransport.
DynEventBuilder
Type alias for a EventBuilder with an underlying DynTransport.
DynInstance
Type alias for an Instance with an underlying DynTransport.
DynMethodBuilder
Type alias for a MethodBuilder with an underlying DynTransport.
DynViewMethodBuilder
Type alias for a ViewMethodBuilder with an underlying DynTransport.
DynWeb3
Type alias for a Web3 with an underlying DynTransport.