DynAllEventsBuilder

Type Alias DynAllEventsBuilder 

pub type DynAllEventsBuilder<E> = AllEventsBuilder<DynTransport, E>;
Type alias for a LogStream with an underlying DynTransport.

Aliased Type

pub struct DynAllEventsBuilder<E> {
    pub filter: LogFilterBuilder<DynTransport>,
    pub deployment_information: Option<DeploymentInformation>,
    /* private fields */
}

Fields

filter: LogFilterBuilder<DynTransport>

The underlying log filter for these contract events.

deployment_information: Option<DeploymentInformation>

The contract deployment transaction hash. Specifying this can increase the performance of the paginated events query.

Note that if the contract was created from an existing deployment that includes the transaction hash, then this property will be automatically set.