Module errors

Module errors 

Module with common error types.

Structs

EventError
Error that can occur while streaming contract events.
InvalidPrivateKey
An error indicating an invalid private key. Private keys for secp256k1 must be exactly 32 bytes and fall within the range [1, n) where n is the order of the generator point of the curve.
MethodError
Error that can occur while executing a contract call or transaction.
ParseParamTypeError
An error representing an error parsing a parameter type.
TryFromBigIntError
The error type that is returned when conversion to or from a 256-bit integer fails.

Enums

ArtifactError
An error in loading or parsing an artifact.
BytecodeError
An error reading bytecode string representation.
DeployError
Error that can occur while locating a deployed contract.
ExecutionError
Error that can occur while executing a contract call or transaction.
LinkError
An error linking a library to bytecode.
ParseI256Error
The error type that is returned when parsing a 256-bit signed integer.