Module ethcontract::log

source ·
This module implements event builders and streams for retrieving events emitted by a contract.

Structs

  • A log filter builder for configuring either a query for past logs or a stream that constantly queries new logs and deals with re-orgs.

Constants