Implementation for setting up, signing, estimating gas and sending transactions on the Ethereum network.
Re-exports
pub use self::gas_price::GasPrice;
Modules
- confirm
- Transaction confirmation implementation. This is a re-implementation of
web3confirmation future to fix issues with development nodes like Ganache where the transaction gets mined right away, so waiting for 1 confirmation would require another transaction to be sent so a new block could mine. Additionally, waiting for 0 confirmations inweb3means that the tx is just sent to the mem-pool but does not wait for it to get mined. Hopefully some of this can move upstream into theweb3crate. - gas_
price - Implementation of gas price estimation.
Structs
- Transaction
Builder - Data used for building a transaction that modifies the blockchain. These transactions can either be sent to be signed locally by the node or can be signed offline.
Enums
- Account
- The account type used for signing the transaction.
- Resolve
Condition - The condition on which a transaction’s
SendFuturegets resolved. - Transaction
- Represents a prepared and optionally signed transaction that is ready for
sending created by a
TransactionBuilder. - Transaction
Result - Represents the result of a sent transaction that can either be a transaction
hash, in the case the transaction was not confirmed, or a full transaction
receipt if the
TransactionBuilderwas configured to wait for confirmation blocks.