Module ethcontract::transport
source · Expand description
Module containing additional transports used by the ethcontract runtime. In
particular, this module includes DynTransport which wraps other valid
transports and using dynamic dispatch to call the underlying transport
implementation. This transport is used by default for generated contract APIs
to help create a more ergonimic experience by making the generated struct not
be generic on the underlying transport (at the small cost of some dynamic
dispatch and extra allocations).
Structs
- Dynamic
Transportimplementation to allow for a generic-free contract API. This type wraps anyTransporttype and implementsTransportitself.