Module ethcontract::batch
source · Expand description
Module containing components to batch multiple contract calls into a single request to the Node.
Structs
- Struct allowing to batch multiple calls into a single Node request
Module containing components to batch multiple contract calls into a single request to the Node.