Module batch

Module batch 

Module containing components to batch multiple contract calls into a single request to the Node.

Structs

CallBatch
Struct allowing to batch multiple calls into a single Node request