Module batch
ethcontract
0.25.6
Module batch
Module Items
Structs
In crate ethcontract
ethcontract
Module
batch
Module containing components to batch multiple contract calls into a single request to the Node.
Structs

Call
Batch
Struct allowing to batch multiple calls into a single Node request