Module ethcontract::contract
source · Expand description
Abstraction for interacting with ethereum smart contracts. Provides methods for sending transactions to contracts as well as querying current contract state.
Structs
- A builder for creating a filtered stream for any contract event.
- Builder for specifying options for deploying a linked contract.
- A contract event
- A builder for creating a filtered stream of contract events that are
- Additional metadata from the log for the event.
- Represents a contract instance at an address. Provides methods for contract interaction.
- Builder for specifying linking options for a contract.
- Data used for building a contract method call or transaction. The method builder can be demoted into a
CallBuilderto not allow sending of transactions. This is useful when dealing with view functions. - Default options to be applied to
MethodBuilderorViewMethodBuilder. - Raw log topics and data for a contract event.
- Method signature with additional info about method’s input and output types.
- Data used for building a contract method call. The view method builder can’t directly send transactions and is for read only method calls.
Enums
- A type representing a contract event that was either added or removed. Note that this type intentionally an enum so that the handling of removed events is made more explicit.
- Acceptable topic possibilities.
Traits
- a factory trait for deployable contract instances. this traits provides functionality for building a deployment and creating instances of a contract type at a given address.
- Trait for parsing a transaction log into an some event data when the expected event type is not known.
Type Aliases
- A contract event from an event stream.