Module contract

Module contract 

Abstraction for interacting with ethereum smart contracts. Provides methods for sending transactions to contracts as well as querying current contract state.

Structs

AllEventsBuilder
A builder for creating a filtered stream for any contract event.
DeployBuilder
Builder for specifying options for deploying a linked contract.
Event
A contract event
EventBuilder
A builder for creating a filtered stream of contract events that are
EventMetadata
Additional metadata from the log for the event.
Instance
Represents a contract instance at an address. Provides methods for contract interaction.
Linker
Builder for specifying linking options for a contract.
MethodBuilder
Data used for building a contract method call or transaction. The method builder can be demoted into a CallBuilder to not allow sending of transactions. This is useful when dealing with view functions.
MethodDefaults
Default options to be applied to MethodBuilder or ViewMethodBuilder.
RawLog
Raw log topics and data for a contract event.
Signature
Method signature with additional info about method’s input and output types.
ViewMethodBuilder
Data used for building a contract method call. The view method builder can’t directly send transactions and is for read only method calls.

Enums

EventStatus
A type representing a contract event that was either added or removed. Note that this type intentionally an enum so that the handling of removed events is made more explicit.
Topic
Acceptable topic possibilities.

Traits

Deploy
a factory trait for deployable contract instances. this traits provides functionality for building a deployment and creating instances of a contract type at a given address.
ParseLog
Trait for parsing a transaction log into an some event data when the expected event type is not known.

Type Aliases

StreamEvent
A contract event from an event stream.