Struct ethcontract::contract::Linker
source · pub struct Linker { /* private fields */ }Expand description
Builder for specifying linking options for a contract.
Implementations
sourceimpl Linker
impl Linker
sourcepub fn library<S>(self, name: S, address: Address) -> Result<Linker, LinkError>
pub fn library<S>(self, name: S, address: Address) -> Result<Linker, LinkError>
Specify a linked library used for this contract. Note that we incrementally link so that we can verify each time a library is linked whether it was successful or not.
Panics
Panics if an invalid library name is used (for example if it is more than 38 characters long).
sourcepub fn deploy<T, P>(
self,
web3: Web3<T>,
params: P
) -> Result<DeployBuilder<T, Instance<T>>, DeployError>
pub fn deploy<T, P>( self, web3: Web3<T>, params: P ) -> Result<DeployBuilder<T, Instance<T>>, DeployError>
Finish linking and check if there are any outstanding unlinked libraries and create a deployment builder.