Module with common error types.
Structs
- Event
Error - Error that can occur while streaming contract events.
- Invalid
Private Key - An error indicating an invalid private key. Private keys for secp256k1 must
be exactly 32 bytes and fall within the range
[1, n)wherenis the order of the generator point of the curve. - Method
Error - Error that can occur while executing a contract call or transaction.
- Parse
Param Type Error - An error representing an error parsing a parameter type.
- TryFrom
BigInt Error - The error type that is returned when conversion to or from a 256-bit integer fails.
Enums
- Artifact
Error - An error in loading or parsing an artifact.
- Bytecode
Error - An error reading bytecode string representation.
- Deploy
Error - Error that can occur while locating a deployed contract.
- Execution
Error - Error that can occur while executing a contract call or transaction.
- Link
Error - An error linking a library to bytecode.
- Parse
I256 Error - The error type that is returned when parsing a 256-bit signed integer.