Enum ethcontract::errors::ExecutionError
source · [−]pub enum ExecutionError {
Show 14 variants
Web3(Web3Error),
AbiDecode(AbiError),
Parse(ParseIntError),
NoLocalAccounts,
Revert(Option<String>),
InvalidOpcode,
ConfirmTimeout(Box<TransactionResult>),
Failure(Box<TransactionReceipt>),
MissingTransaction(H256),
PendingTransaction(H256),
RemovedLog(Box<Log>),
StreamEndedUnexpectedly,
Tokenization(Error),
UnexpectedTransactionHash,
}Expand description
Error that can occur while executing a contract call or transaction.
Variants
Web3(Web3Error)
An error occured while performing a web3 call.
AbiDecode(AbiError)
An error occured while ABI decoding the result of a contract method call.
Parse(ParseIntError)
An error occured while parsing chain ID received from a Web3 call.
NoLocalAccounts
An error indicating that an attempt was made to build or send a locally signed transaction to a node without any local accounts.
Revert(Option<String>)
A contract call reverted.
InvalidOpcode
A contract call executed an invalid opcode.
ConfirmTimeout(Box<TransactionResult>)
A contract transaction failed to confirm within the block timeout limit.
Failure(Box<TransactionReceipt>)
Transaction failure (e.g. out of gas or revert).
MissingTransaction(H256)
Failed to find a transaction by hash.
PendingTransaction(H256)
Failed to get a block for a pending transaction that has not yet been mined.
RemovedLog(Box<Log>)
A removed log was received when querying past logs.
StreamEndedUnexpectedly
A stream ended unexpectedly.
Tokenization(Error)
A tokenization related error.
UnexpectedTransactionHash
Unexpected transaction hash