Module ethcontract::log
source · Expand description
This module implements event builders and streams for retrieving events emitted by a contract.
Structs
- A log filter builder for configuring either a query for past logs or a stream that constantly queries new logs and deals with re-orgs.
Constants
- The default block page size used for querying past events.
- The default poll interval to use for polling logs from the block chain.